# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   | 406  | Error. Not Acceptable  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class GetAccountPlan(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'credits_type': 'str',
        'credits': 'float',
        'start_date': 'date',
        'end_date': 'date',
        'user_limit': 'int'
    }

    attribute_map = {
        'type': 'type',
        'credits_type': 'creditsType',
        'credits': 'credits',
        'start_date': 'startDate',
        'end_date': 'endDate',
        'user_limit': 'userLimit'
    }

    def __init__(self, type=None, credits_type=None, credits=None, start_date=None, end_date=None, user_limit=None):  # noqa: E501
        """GetAccountPlan - a model defined in Swagger"""  # noqa: E501

        self._type = None
        self._credits_type = None
        self._credits = None
        self._start_date = None
        self._end_date = None
        self._user_limit = None
        self.discriminator = None

        self.type = type
        self.credits_type = credits_type
        self.credits = credits
        if start_date is not None:
            self.start_date = start_date
        if end_date is not None:
            self.end_date = end_date
        if user_limit is not None:
            self.user_limit = user_limit

    @property
    def type(self):
        """Gets the type of this GetAccountPlan.  # noqa: E501

        Displays the plan type of the user  # noqa: E501

        :return: The type of this GetAccountPlan.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this GetAccountPlan.

        Displays the plan type of the user  # noqa: E501

        :param type: The type of this GetAccountPlan.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["payAsYouGo", "free", "subscription", "sms", "reseller"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def credits_type(self):
        """Gets the credits_type of this GetAccountPlan.  # noqa: E501

        This is the type of the credit, \"Send Limit\" is one of the possible types of credit of a user. \"Send Limit\" implies the total number of emails you can send to the subscribers in your account.  # noqa: E501

        :return: The credits_type of this GetAccountPlan.  # noqa: E501
        :rtype: str
        """
        return self._credits_type

    @credits_type.setter
    def credits_type(self, credits_type):
        """Sets the credits_type of this GetAccountPlan.

        This is the type of the credit, \"Send Limit\" is one of the possible types of credit of a user. \"Send Limit\" implies the total number of emails you can send to the subscribers in your account.  # noqa: E501

        :param credits_type: The credits_type of this GetAccountPlan.  # noqa: E501
        :type: str
        """
        if credits_type is None:
            raise ValueError("Invalid value for `credits_type`, must not be `None`")  # noqa: E501
        allowed_values = ["sendLimit"]  # noqa: E501
        if credits_type not in allowed_values:
            raise ValueError(
                "Invalid value for `credits_type` ({0}), must be one of {1}"  # noqa: E501
                .format(credits_type, allowed_values)
            )

        self._credits_type = credits_type

    @property
    def credits(self):
        """Gets the credits of this GetAccountPlan.  # noqa: E501

        Remaining credits of the user  # noqa: E501

        :return: The credits of this GetAccountPlan.  # noqa: E501
        :rtype: float
        """
        return self._credits

    @credits.setter
    def credits(self, credits):
        """Sets the credits of this GetAccountPlan.

        Remaining credits of the user  # noqa: E501

        :param credits: The credits of this GetAccountPlan.  # noqa: E501
        :type: float
        """
        if credits is None:
            raise ValueError("Invalid value for `credits`, must not be `None`")  # noqa: E501

        self._credits = credits

    @property
    def start_date(self):
        """Gets the start_date of this GetAccountPlan.  # noqa: E501

        Date of the period from which the plan will start (only available for \"subscription\" and \"reseller\" plan type)  # noqa: E501

        :return: The start_date of this GetAccountPlan.  # noqa: E501
        :rtype: date
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this GetAccountPlan.

        Date of the period from which the plan will start (only available for \"subscription\" and \"reseller\" plan type)  # noqa: E501

        :param start_date: The start_date of this GetAccountPlan.  # noqa: E501
        :type: date
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this GetAccountPlan.  # noqa: E501

        Date of the period from which the plan will end (only available for \"subscription\" and \"reseller\" plan type)  # noqa: E501

        :return: The end_date of this GetAccountPlan.  # noqa: E501
        :rtype: date
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this GetAccountPlan.

        Date of the period from which the plan will end (only available for \"subscription\" and \"reseller\" plan type)  # noqa: E501

        :param end_date: The end_date of this GetAccountPlan.  # noqa: E501
        :type: date
        """

        self._end_date = end_date

    @property
    def user_limit(self):
        """Gets the user_limit of this GetAccountPlan.  # noqa: E501

        Only in case of reseller account. It implies the total number of child accounts you can add to your account.  # noqa: E501

        :return: The user_limit of this GetAccountPlan.  # noqa: E501
        :rtype: int
        """
        return self._user_limit

    @user_limit.setter
    def user_limit(self, user_limit):
        """Sets the user_limit of this GetAccountPlan.

        Only in case of reseller account. It implies the total number of child accounts you can add to your account.  # noqa: E501

        :param user_limit: The user_limit of this GetAccountPlan.  # noqa: E501
        :type: int
        """

        self._user_limit = user_limit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetAccountPlan, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetAccountPlan):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   | 406  | Error. Not Acceptable  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from sib_api_v3_sdk.api_client import ApiClient


class SMSCampaignsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_sms_campaign(self, create_sms_campaign, **kwargs):  # noqa: E501
        """Creates an SMS campaign  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_sms_campaign(create_sms_campaign, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateSmsCampaign create_sms_campaign: Values to create an SMS Campaign (required)
        :return: CreateModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_sms_campaign_with_http_info(create_sms_campaign, **kwargs)  # noqa: E501
        else:
            (data) = self.create_sms_campaign_with_http_info(create_sms_campaign, **kwargs)  # noqa: E501
            return data

    def create_sms_campaign_with_http_info(self, create_sms_campaign, **kwargs):  # noqa: E501
        """Creates an SMS campaign  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_sms_campaign_with_http_info(create_sms_campaign, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateSmsCampaign create_sms_campaign: Values to create an SMS Campaign (required)
        :return: CreateModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['create_sms_campaign']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_sms_campaign" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'create_sms_campaign' is set
        if ('create_sms_campaign' not in params or
                params['create_sms_campaign'] is None):
            raise ValueError("Missing the required parameter `create_sms_campaign` when calling `create_sms_campaign`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_sms_campaign' in params:
            body_params = params['create_sms_campaign']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smsCampaigns', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_sms_campaign(self, campaign_id, **kwargs):  # noqa: E501
        """Delete the SMS campaign  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_sms_campaign(campaign_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int campaign_id: id of the SMS campaign (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_sms_campaign_with_http_info(campaign_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_sms_campaign_with_http_info(campaign_id, **kwargs)  # noqa: E501
            return data

    def delete_sms_campaign_with_http_info(self, campaign_id, **kwargs):  # noqa: E501
        """Delete the SMS campaign  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_sms_campaign_with_http_info(campaign_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int campaign_id: id of the SMS campaign (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['campaign_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_sms_campaign" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'campaign_id' is set
        if ('campaign_id' not in params or
                params['campaign_id'] is None):
            raise ValueError("Missing the required parameter `campaign_id` when calling `delete_sms_campaign`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'campaign_id' in params:
            path_params['campaignId'] = params['campaign_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smsCampaigns/{campaignId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sms_campaign(self, campaign_id, **kwargs):  # noqa: E501
        """Get an SMS campaign  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sms_campaign(campaign_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int campaign_id: id of the SMS campaign (required)
        :return: GetSmsCampaign
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_sms_campaign_with_http_info(campaign_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_sms_campaign_with_http_info(campaign_id, **kwargs)  # noqa: E501
            return data

    def get_sms_campaign_with_http_info(self, campaign_id, **kwargs):  # noqa: E501
        """Get an SMS campaign  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sms_campaign_with_http_info(campaign_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int campaign_id: id of the SMS campaign (required)
        :return: GetSmsCampaign
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['campaign_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sms_campaign" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'campaign_id' is set
        if ('campaign_id' not in params or
                params['campaign_id'] is None):
            raise ValueError("Missing the required parameter `campaign_id` when calling `get_sms_campaign`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'campaign_id' in params:
            path_params['campaignId'] = params['campaign_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smsCampaigns/{campaignId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetSmsCampaign',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sms_campaigns(self, **kwargs):  # noqa: E501
        """Returns the informations for all your created SMS campaigns  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sms_campaigns(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str status: Status of campaign.
        :param datetime start_date: Mandatory if endDate is used. Starting (urlencoded) UTC date-time (YYYY-MM-DDTHH:mm:ss.SSSZ) to filter the sent sms campaigns. Prefer to pass your timezone in date-time format for accurate result ( only available if either 'status' not passed and if passed is set to 'sent' )
        :param datetime end_date: Mandatory if startDate is used. Ending (urlencoded) UTC date-time (YYYY-MM-DDTHH:mm:ss.SSSZ) to filter the sent sms campaigns. Prefer to pass your timezone in date-time format for accurate result ( only available if either 'status' not passed and if passed is set to 'sent' )
        :param int limit: Number limitation for the result returned
        :param int offset: Beginning point in the list to retrieve from.
        :return: GetSmsCampaigns
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_sms_campaigns_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_sms_campaigns_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_sms_campaigns_with_http_info(self, **kwargs):  # noqa: E501
        """Returns the informations for all your created SMS campaigns  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sms_campaigns_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str status: Status of campaign.
        :param datetime start_date: Mandatory if endDate is used. Starting (urlencoded) UTC date-time (YYYY-MM-DDTHH:mm:ss.SSSZ) to filter the sent sms campaigns. Prefer to pass your timezone in date-time format for accurate result ( only available if either 'status' not passed and if passed is set to 'sent' )
        :param datetime end_date: Mandatory if startDate is used. Ending (urlencoded) UTC date-time (YYYY-MM-DDTHH:mm:ss.SSSZ) to filter the sent sms campaigns. Prefer to pass your timezone in date-time format for accurate result ( only available if either 'status' not passed and if passed is set to 'sent' )
        :param int limit: Number limitation for the result returned
        :param int offset: Beginning point in the list to retrieve from.
        :return: GetSmsCampaigns
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['status', 'start_date', 'end_date', 'limit', 'offset']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sms_campaigns" % key
                )
            params[key] = val
        del params['kwargs']

        if 'limit' in params and params['limit'] > 1000:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_sms_campaigns`, must be a value less than or equal to `1000`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'status' in params:
            query_params.append(('status', params['status']))  # noqa: E501
        if 'start_date' in params:
            query_params.append(('startDate', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('endDate', params['end_date']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smsCampaigns', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetSmsCampaigns',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def request_sms_recipient_export(self, campaign_id, **kwargs):  # noqa: E501
        """Exports the recipients of the specified campaign.  # noqa: E501

        It returns the background process ID which on completion calls the notify URL that you have set in the input.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.request_sms_recipient_export(campaign_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int campaign_id: id of the campaign (required)
        :param RequestSmsRecipientExport recipient_export: Values to send for a recipient export request
        :return: CreatedProcessId
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.request_sms_recipient_export_with_http_info(campaign_id, **kwargs)  # noqa: E501
        else:
            (data) = self.request_sms_recipient_export_with_http_info(campaign_id, **kwargs)  # noqa: E501
            return data

    def request_sms_recipient_export_with_http_info(self, campaign_id, **kwargs):  # noqa: E501
        """Exports the recipients of the specified campaign.  # noqa: E501

        It returns the background process ID which on completion calls the notify URL that you have set in the input.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.request_sms_recipient_export_with_http_info(campaign_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int campaign_id: id of the campaign (required)
        :param RequestSmsRecipientExport recipient_export: Values to send for a recipient export request
        :return: CreatedProcessId
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['campaign_id', 'recipient_export']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method request_sms_recipient_export" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'campaign_id' is set
        if ('campaign_id' not in params or
                params['campaign_id'] is None):
            raise ValueError("Missing the required parameter `campaign_id` when calling `request_sms_recipient_export`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'campaign_id' in params:
            path_params['campaignId'] = params['campaign_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'recipient_export' in params:
            body_params = params['recipient_export']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smsCampaigns/{campaignId}/exportRecipients', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreatedProcessId',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def send_sms_campaign_now(self, campaign_id, **kwargs):  # noqa: E501
        """Send your SMS campaign immediately  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_sms_campaign_now(campaign_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int campaign_id: id of the campaign (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.send_sms_campaign_now_with_http_info(campaign_id, **kwargs)  # noqa: E501
        else:
            (data) = self.send_sms_campaign_now_with_http_info(campaign_id, **kwargs)  # noqa: E501
            return data

    def send_sms_campaign_now_with_http_info(self, campaign_id, **kwargs):  # noqa: E501
        """Send your SMS campaign immediately  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_sms_campaign_now_with_http_info(campaign_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int campaign_id: id of the campaign (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['campaign_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_sms_campaign_now" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'campaign_id' is set
        if ('campaign_id' not in params or
                params['campaign_id'] is None):
            raise ValueError("Missing the required parameter `campaign_id` when calling `send_sms_campaign_now`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'campaign_id' in params:
            path_params['campaignId'] = params['campaign_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smsCampaigns/{campaignId}/sendNow', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def send_sms_report(self, campaign_id, send_report, **kwargs):  # noqa: E501
        """Send report of SMS campaigns  # noqa: E501

        Send report of Sent and Archived campaign, to the specified email addresses, with respective data and a pdf attachment in detail.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_sms_report(campaign_id, send_report, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int campaign_id: id of the campaign (required)
        :param SendReport send_report: Values for send a report (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.send_sms_report_with_http_info(campaign_id, send_report, **kwargs)  # noqa: E501
        else:
            (data) = self.send_sms_report_with_http_info(campaign_id, send_report, **kwargs)  # noqa: E501
            return data

    def send_sms_report_with_http_info(self, campaign_id, send_report, **kwargs):  # noqa: E501
        """Send report of SMS campaigns  # noqa: E501

        Send report of Sent and Archived campaign, to the specified email addresses, with respective data and a pdf attachment in detail.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_sms_report_with_http_info(campaign_id, send_report, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int campaign_id: id of the campaign (required)
        :param SendReport send_report: Values for send a report (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['campaign_id', 'send_report']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_sms_report" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'campaign_id' is set
        if ('campaign_id' not in params or
                params['campaign_id'] is None):
            raise ValueError("Missing the required parameter `campaign_id` when calling `send_sms_report`")  # noqa: E501
        # verify the required parameter 'send_report' is set
        if ('send_report' not in params or
                params['send_report'] is None):
            raise ValueError("Missing the required parameter `send_report` when calling `send_sms_report`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'campaign_id' in params:
            path_params['campaignId'] = params['campaign_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'send_report' in params:
            body_params = params['send_report']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smsCampaigns/{campaignId}/sendReport', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def send_test_sms(self, campaign_id, phone_number, **kwargs):  # noqa: E501
        """Send an SMS  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_test_sms(campaign_id, phone_number, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int campaign_id: Id of the SMS campaign (required)
        :param SendTestSms phone_number: Mobile number of the recipient with the country code. This number must belong to one of your contacts in SendinBlue account and must not be blacklisted (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.send_test_sms_with_http_info(campaign_id, phone_number, **kwargs)  # noqa: E501
        else:
            (data) = self.send_test_sms_with_http_info(campaign_id, phone_number, **kwargs)  # noqa: E501
            return data

    def send_test_sms_with_http_info(self, campaign_id, phone_number, **kwargs):  # noqa: E501
        """Send an SMS  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_test_sms_with_http_info(campaign_id, phone_number, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int campaign_id: Id of the SMS campaign (required)
        :param SendTestSms phone_number: Mobile number of the recipient with the country code. This number must belong to one of your contacts in SendinBlue account and must not be blacklisted (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['campaign_id', 'phone_number']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_test_sms" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'campaign_id' is set
        if ('campaign_id' not in params or
                params['campaign_id'] is None):
            raise ValueError("Missing the required parameter `campaign_id` when calling `send_test_sms`")  # noqa: E501
        # verify the required parameter 'phone_number' is set
        if ('phone_number' not in params or
                params['phone_number'] is None):
            raise ValueError("Missing the required parameter `phone_number` when calling `send_test_sms`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'campaign_id' in params:
            path_params['campaignId'] = params['campaign_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'phone_number' in params:
            body_params = params['phone_number']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smsCampaigns/{campaignId}/sendTest', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_sms_campaign(self, campaign_id, update_sms_campaign, **kwargs):  # noqa: E501
        """Updates an SMS campaign  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_sms_campaign(campaign_id, update_sms_campaign, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int campaign_id: id of the SMS campaign (required)
        :param UpdateSmsCampaign update_sms_campaign: Values to update an SMS Campaign (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_sms_campaign_with_http_info(campaign_id, update_sms_campaign, **kwargs)  # noqa: E501
        else:
            (data) = self.update_sms_campaign_with_http_info(campaign_id, update_sms_campaign, **kwargs)  # noqa: E501
            return data

    def update_sms_campaign_with_http_info(self, campaign_id, update_sms_campaign, **kwargs):  # noqa: E501
        """Updates an SMS campaign  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_sms_campaign_with_http_info(campaign_id, update_sms_campaign, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int campaign_id: id of the SMS campaign (required)
        :param UpdateSmsCampaign update_sms_campaign: Values to update an SMS Campaign (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['campaign_id', 'update_sms_campaign']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_sms_campaign" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'campaign_id' is set
        if ('campaign_id' not in params or
                params['campaign_id'] is None):
            raise ValueError("Missing the required parameter `campaign_id` when calling `update_sms_campaign`")  # noqa: E501
        # verify the required parameter 'update_sms_campaign' is set
        if ('update_sms_campaign' not in params or
                params['update_sms_campaign'] is None):
            raise ValueError("Missing the required parameter `update_sms_campaign` when calling `update_sms_campaign`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'campaign_id' in params:
            path_params['campaignId'] = params['campaign_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_sms_campaign' in params:
            body_params = params['update_sms_campaign']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smsCampaigns/{campaignId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_sms_campaign_status(self, campaign_id, status, **kwargs):  # noqa: E501
        """Update the campaign status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_sms_campaign_status(campaign_id, status, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int campaign_id: id of the campaign (required)
        :param UpdateCampaignStatus status: Status of the campaign. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_sms_campaign_status_with_http_info(campaign_id, status, **kwargs)  # noqa: E501
        else:
            (data) = self.update_sms_campaign_status_with_http_info(campaign_id, status, **kwargs)  # noqa: E501
            return data

    def update_sms_campaign_status_with_http_info(self, campaign_id, status, **kwargs):  # noqa: E501
        """Update the campaign status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_sms_campaign_status_with_http_info(campaign_id, status, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int campaign_id: id of the campaign (required)
        :param UpdateCampaignStatus status: Status of the campaign. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['campaign_id', 'status']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_sms_campaign_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'campaign_id' is set
        if ('campaign_id' not in params or
                params['campaign_id'] is None):
            raise ValueError("Missing the required parameter `campaign_id` when calling `update_sms_campaign_status`")  # noqa: E501
        # verify the required parameter 'status' is set
        if ('status' not in params or
                params['status'] is None):
            raise ValueError("Missing the required parameter `status` when calling `update_sms_campaign_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'campaign_id' in params:
            path_params['campaignId'] = params['campaign_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'status' in params:
            body_params = params['status']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smsCampaigns/{campaignId}/status', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   | 406  | Error. Not Acceptable  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class GetTransacEmailContent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'email': 'str',
        'subject': 'str',
        'template_id': 'int',
        '_date': 'datetime',
        'events': 'list[GetTransacEmailContentEvents]',
        'body': 'str',
        'attachment_count': 'int'
    }

    attribute_map = {
        'email': 'email',
        'subject': 'subject',
        'template_id': 'templateId',
        '_date': 'date',
        'events': 'events',
        'body': 'body',
        'attachment_count': 'attachmentCount'
    }

    def __init__(self, email=None, subject=None, template_id=None, _date=None, events=None, body=None, attachment_count=None):  # noqa: E501
        """GetTransacEmailContent - a model defined in Swagger"""  # noqa: E501

        self._email = None
        self._subject = None
        self._template_id = None
        self.__date = None
        self._events = None
        self._body = None
        self._attachment_count = None
        self.discriminator = None

        self.email = email
        self.subject = subject
        if template_id is not None:
            self.template_id = template_id
        self._date = _date
        self.events = events
        self.body = body
        self.attachment_count = attachment_count

    @property
    def email(self):
        """Gets the email of this GetTransacEmailContent.  # noqa: E501

        Email address to which transactional email has been sent  # noqa: E501

        :return: The email of this GetTransacEmailContent.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this GetTransacEmailContent.

        Email address to which transactional email has been sent  # noqa: E501

        :param email: The email of this GetTransacEmailContent.  # noqa: E501
        :type: str
        """
        if email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def subject(self):
        """Gets the subject of this GetTransacEmailContent.  # noqa: E501

        Subject of the sent email  # noqa: E501

        :return: The subject of this GetTransacEmailContent.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this GetTransacEmailContent.

        Subject of the sent email  # noqa: E501

        :param subject: The subject of this GetTransacEmailContent.  # noqa: E501
        :type: str
        """
        if subject is None:
            raise ValueError("Invalid value for `subject`, must not be `None`")  # noqa: E501

        self._subject = subject

    @property
    def template_id(self):
        """Gets the template_id of this GetTransacEmailContent.  # noqa: E501

        Id of the template  # noqa: E501

        :return: The template_id of this GetTransacEmailContent.  # noqa: E501
        :rtype: int
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this GetTransacEmailContent.

        Id of the template  # noqa: E501

        :param template_id: The template_id of this GetTransacEmailContent.  # noqa: E501
        :type: int
        """

        self._template_id = template_id

    @property
    def _date(self):
        """Gets the _date of this GetTransacEmailContent.  # noqa: E501

        Date on which transactional email was sent  # noqa: E501

        :return: The _date of this GetTransacEmailContent.  # noqa: E501
        :rtype: datetime
        """
        return self.__date

    @_date.setter
    def _date(self, _date):
        """Sets the _date of this GetTransacEmailContent.

        Date on which transactional email was sent  # noqa: E501

        :param _date: The _date of this GetTransacEmailContent.  # noqa: E501
        :type: datetime
        """
        if _date is None:
            raise ValueError("Invalid value for `_date`, must not be `None`")  # noqa: E501

        self.__date = _date

    @property
    def events(self):
        """Gets the events of this GetTransacEmailContent.  # noqa: E501

        Series of events which occurred on the transactional email  # noqa: E501

        :return: The events of this GetTransacEmailContent.  # noqa: E501
        :rtype: list[GetTransacEmailContentEvents]
        """
        return self._events

    @events.setter
    def events(self, events):
        """Sets the events of this GetTransacEmailContent.

        Series of events which occurred on the transactional email  # noqa: E501

        :param events: The events of this GetTransacEmailContent.  # noqa: E501
        :type: list[GetTransacEmailContentEvents]
        """
        if events is None:
            raise ValueError("Invalid value for `events`, must not be `None`")  # noqa: E501

        self._events = events

    @property
    def body(self):
        """Gets the body of this GetTransacEmailContent.  # noqa: E501

        Actual content of the transactional email that has been sent  # noqa: E501

        :return: The body of this GetTransacEmailContent.  # noqa: E501
        :rtype: str
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this GetTransacEmailContent.

        Actual content of the transactional email that has been sent  # noqa: E501

        :param body: The body of this GetTransacEmailContent.  # noqa: E501
        :type: str
        """
        if body is None:
            raise ValueError("Invalid value for `body`, must not be `None`")  # noqa: E501

        self._body = body

    @property
    def attachment_count(self):
        """Gets the attachment_count of this GetTransacEmailContent.  # noqa: E501

        Count of the attachments that were sent in the email  # noqa: E501

        :return: The attachment_count of this GetTransacEmailContent.  # noqa: E501
        :rtype: int
        """
        return self._attachment_count

    @attachment_count.setter
    def attachment_count(self, attachment_count):
        """Sets the attachment_count of this GetTransacEmailContent.

        Count of the attachments that were sent in the email  # noqa: E501

        :param attachment_count: The attachment_count of this GetTransacEmailContent.  # noqa: E501
        :type: int
        """
        if attachment_count is None:
            raise ValueError("Invalid value for `attachment_count`, must not be `None`")  # noqa: E501

        self._attachment_count = attachment_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetTransacEmailContent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetTransacEmailContent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   | 406  | Error. Not Acceptable  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "sib-api-v3-sdk"
VERSION = "6.1.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "certifi>=2017.4.17",
    "python-dateutil>=2.1",
    "six>=1.10",
    "urllib3>=1.23"
]
    

setup(
    name=NAME,
    version=VERSION,
    description="SendinBlue API",
    author_email="contact@sendinblue.com",
    url="",
    keywords=["Swagger", "SendinBlue API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True
)



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   | 406  | Error. Not Acceptable  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class AbTestCampaignResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'winning_version': 'str',
        'winning_criteria': 'str',
        'winning_subject_line': 'str',
        'open_rate': 'str',
        'click_rate': 'str',
        'winning_version_rate': 'str'
    }

    attribute_map = {
        'winning_version': 'winningVersion',
        'winning_criteria': 'winningCriteria',
        'winning_subject_line': 'winningSubjectLine',
        'open_rate': 'openRate',
        'click_rate': 'clickRate',
        'winning_version_rate': 'winningVersionRate'
    }

    def __init__(self, winning_version=None, winning_criteria=None, winning_subject_line=None, open_rate=None, click_rate=None, winning_version_rate=None):  # noqa: E501
        """AbTestCampaignResult - a model defined in Swagger"""  # noqa: E501

        self._winning_version = None
        self._winning_criteria = None
        self._winning_subject_line = None
        self._open_rate = None
        self._click_rate = None
        self._winning_version_rate = None
        self.discriminator = None

        if winning_version is not None:
            self.winning_version = winning_version
        if winning_criteria is not None:
            self.winning_criteria = winning_criteria
        if winning_subject_line is not None:
            self.winning_subject_line = winning_subject_line
        if open_rate is not None:
            self.open_rate = open_rate
        if click_rate is not None:
            self.click_rate = click_rate
        if winning_version_rate is not None:
            self.winning_version_rate = winning_version_rate

    @property
    def winning_version(self):
        """Gets the winning_version of this AbTestCampaignResult.  # noqa: E501

        Winning Campaign Info. pending = Campaign has been picked for sending and winning version is yet to be decided, tie = A tie happened between both the versions, notAvailable = Campaign has not yet been picked for sending.  # noqa: E501

        :return: The winning_version of this AbTestCampaignResult.  # noqa: E501
        :rtype: str
        """
        return self._winning_version

    @winning_version.setter
    def winning_version(self, winning_version):
        """Sets the winning_version of this AbTestCampaignResult.

        Winning Campaign Info. pending = Campaign has been picked for sending and winning version is yet to be decided, tie = A tie happened between both the versions, notAvailable = Campaign has not yet been picked for sending.  # noqa: E501

        :param winning_version: The winning_version of this AbTestCampaignResult.  # noqa: E501
        :type: str
        """
        allowed_values = ["notAvailable", "pending", "tie", "A", "B"]  # noqa: E501
        if winning_version not in allowed_values:
            raise ValueError(
                "Invalid value for `winning_version` ({0}), must be one of {1}"  # noqa: E501
                .format(winning_version, allowed_values)
            )

        self._winning_version = winning_version

    @property
    def winning_criteria(self):
        """Gets the winning_criteria of this AbTestCampaignResult.  # noqa: E501

        Criteria choosen for winning version (Open/Click)  # noqa: E501

        :return: The winning_criteria of this AbTestCampaignResult.  # noqa: E501
        :rtype: str
        """
        return self._winning_criteria

    @winning_criteria.setter
    def winning_criteria(self, winning_criteria):
        """Sets the winning_criteria of this AbTestCampaignResult.

        Criteria choosen for winning version (Open/Click)  # noqa: E501

        :param winning_criteria: The winning_criteria of this AbTestCampaignResult.  # noqa: E501
        :type: str
        """
        allowed_values = ["Open", "Click"]  # noqa: E501
        if winning_criteria not in allowed_values:
            raise ValueError(
                "Invalid value for `winning_criteria` ({0}), must be one of {1}"  # noqa: E501
                .format(winning_criteria, allowed_values)
            )

        self._winning_criteria = winning_criteria

    @property
    def winning_subject_line(self):
        """Gets the winning_subject_line of this AbTestCampaignResult.  # noqa: E501

        Subject Line of current winning version  # noqa: E501

        :return: The winning_subject_line of this AbTestCampaignResult.  # noqa: E501
        :rtype: str
        """
        return self._winning_subject_line

    @winning_subject_line.setter
    def winning_subject_line(self, winning_subject_line):
        """Sets the winning_subject_line of this AbTestCampaignResult.

        Subject Line of current winning version  # noqa: E501

        :param winning_subject_line: The winning_subject_line of this AbTestCampaignResult.  # noqa: E501
        :type: str
        """

        self._winning_subject_line = winning_subject_line

    @property
    def open_rate(self):
        """Gets the open_rate of this AbTestCampaignResult.  # noqa: E501

        Open rate for current winning version  # noqa: E501

        :return: The open_rate of this AbTestCampaignResult.  # noqa: E501
        :rtype: str
        """
        return self._open_rate

    @open_rate.setter
    def open_rate(self, open_rate):
        """Sets the open_rate of this AbTestCampaignResult.

        Open rate for current winning version  # noqa: E501

        :param open_rate: The open_rate of this AbTestCampaignResult.  # noqa: E501
        :type: str
        """

        self._open_rate = open_rate

    @property
    def click_rate(self):
        """Gets the click_rate of this AbTestCampaignResult.  # noqa: E501

        Click rate for current winning version  # noqa: E501

        :return: The click_rate of this AbTestCampaignResult.  # noqa: E501
        :rtype: str
        """
        return self._click_rate

    @click_rate.setter
    def click_rate(self, click_rate):
        """Sets the click_rate of this AbTestCampaignResult.

        Click rate for current winning version  # noqa: E501

        :param click_rate: The click_rate of this AbTestCampaignResult.  # noqa: E501
        :type: str
        """

        self._click_rate = click_rate

    @property
    def winning_version_rate(self):
        """Gets the winning_version_rate of this AbTestCampaignResult.  # noqa: E501

        Open/Click rate for the winner version  # noqa: E501

        :return: The winning_version_rate of this AbTestCampaignResult.  # noqa: E501
        :rtype: str
        """
        return self._winning_version_rate

    @winning_version_rate.setter
    def winning_version_rate(self, winning_version_rate):
        """Sets the winning_version_rate of this AbTestCampaignResult.

        Open/Click rate for the winner version  # noqa: E501

        :param winning_version_rate: The winning_version_rate of this AbTestCampaignResult.  # noqa: E501
        :type: str
        """

        self._winning_version_rate = winning_version_rate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AbTestCampaignResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AbTestCampaignResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   | 406  | Error. Not Acceptable  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class GetSmsCampaignStats(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'delivered': 'int',
        'sent': 'int',
        'processing': 'int',
        'soft_bounces': 'int',
        'hard_bounces': 'int',
        'unsubscriptions': 'int',
        'answered': 'int'
    }

    attribute_map = {
        'delivered': 'delivered',
        'sent': 'sent',
        'processing': 'processing',
        'soft_bounces': 'softBounces',
        'hard_bounces': 'hardBounces',
        'unsubscriptions': 'unsubscriptions',
        'answered': 'answered'
    }

    def __init__(self, delivered=None, sent=None, processing=None, soft_bounces=None, hard_bounces=None, unsubscriptions=None, answered=None):  # noqa: E501
        """GetSmsCampaignStats - a model defined in Swagger"""  # noqa: E501

        self._delivered = None
        self._sent = None
        self._processing = None
        self._soft_bounces = None
        self._hard_bounces = None
        self._unsubscriptions = None
        self._answered = None
        self.discriminator = None

        self.delivered = delivered
        self.sent = sent
        self.processing = processing
        self.soft_bounces = soft_bounces
        self.hard_bounces = hard_bounces
        self.unsubscriptions = unsubscriptions
        self.answered = answered

    @property
    def delivered(self):
        """Gets the delivered of this GetSmsCampaignStats.  # noqa: E501

        Number of delivered SMS  # noqa: E501

        :return: The delivered of this GetSmsCampaignStats.  # noqa: E501
        :rtype: int
        """
        return self._delivered

    @delivered.setter
    def delivered(self, delivered):
        """Sets the delivered of this GetSmsCampaignStats.

        Number of delivered SMS  # noqa: E501

        :param delivered: The delivered of this GetSmsCampaignStats.  # noqa: E501
        :type: int
        """
        if delivered is None:
            raise ValueError("Invalid value for `delivered`, must not be `None`")  # noqa: E501

        self._delivered = delivered

    @property
    def sent(self):
        """Gets the sent of this GetSmsCampaignStats.  # noqa: E501

        Number of sent SMS  # noqa: E501

        :return: The sent of this GetSmsCampaignStats.  # noqa: E501
        :rtype: int
        """
        return self._sent

    @sent.setter
    def sent(self, sent):
        """Sets the sent of this GetSmsCampaignStats.

        Number of sent SMS  # noqa: E501

        :param sent: The sent of this GetSmsCampaignStats.  # noqa: E501
        :type: int
        """
        if sent is None:
            raise ValueError("Invalid value for `sent`, must not be `None`")  # noqa: E501

        self._sent = sent

    @property
    def processing(self):
        """Gets the processing of this GetSmsCampaignStats.  # noqa: E501

        Number of processing SMS  # noqa: E501

        :return: The processing of this GetSmsCampaignStats.  # noqa: E501
        :rtype: int
        """
        return self._processing

    @processing.setter
    def processing(self, processing):
        """Sets the processing of this GetSmsCampaignStats.

        Number of processing SMS  # noqa: E501

        :param processing: The processing of this GetSmsCampaignStats.  # noqa: E501
        :type: int
        """
        if processing is None:
            raise ValueError("Invalid value for `processing`, must not be `None`")  # noqa: E501

        self._processing = processing

    @property
    def soft_bounces(self):
        """Gets the soft_bounces of this GetSmsCampaignStats.  # noqa: E501

        Number of softbounced SMS  # noqa: E501

        :return: The soft_bounces of this GetSmsCampaignStats.  # noqa: E501
        :rtype: int
        """
        return self._soft_bounces

    @soft_bounces.setter
    def soft_bounces(self, soft_bounces):
        """Sets the soft_bounces of this GetSmsCampaignStats.

        Number of softbounced SMS  # noqa: E501

        :param soft_bounces: The soft_bounces of this GetSmsCampaignStats.  # noqa: E501
        :type: int
        """
        if soft_bounces is None:
            raise ValueError("Invalid value for `soft_bounces`, must not be `None`")  # noqa: E501

        self._soft_bounces = soft_bounces

    @property
    def hard_bounces(self):
        """Gets the hard_bounces of this GetSmsCampaignStats.  # noqa: E501

        Number of hardbounced SMS  # noqa: E501

        :return: The hard_bounces of this GetSmsCampaignStats.  # noqa: E501
        :rtype: int
        """
        return self._hard_bounces

    @hard_bounces.setter
    def hard_bounces(self, hard_bounces):
        """Sets the hard_bounces of this GetSmsCampaignStats.

        Number of hardbounced SMS  # noqa: E501

        :param hard_bounces: The hard_bounces of this GetSmsCampaignStats.  # noqa: E501
        :type: int
        """
        if hard_bounces is None:
            raise ValueError("Invalid value for `hard_bounces`, must not be `None`")  # noqa: E501

        self._hard_bounces = hard_bounces

    @property
    def unsubscriptions(self):
        """Gets the unsubscriptions of this GetSmsCampaignStats.  # noqa: E501

        Number of unsubscription SMS  # noqa: E501

        :return: The unsubscriptions of this GetSmsCampaignStats.  # noqa: E501
        :rtype: int
        """
        return self._unsubscriptions

    @unsubscriptions.setter
    def unsubscriptions(self, unsubscriptions):
        """Sets the unsubscriptions of this GetSmsCampaignStats.

        Number of unsubscription SMS  # noqa: E501

        :param unsubscriptions: The unsubscriptions of this GetSmsCampaignStats.  # noqa: E501
        :type: int
        """
        if unsubscriptions is None:
            raise ValueError("Invalid value for `unsubscriptions`, must not be `None`")  # noqa: E501

        self._unsubscriptions = unsubscriptions

    @property
    def answered(self):
        """Gets the answered of this GetSmsCampaignStats.  # noqa: E501

        Number of replies to the SMS  # noqa: E501

        :return: The answered of this GetSmsCampaignStats.  # noqa: E501
        :rtype: int
        """
        return self._answered

    @answered.setter
    def answered(self, answered):
        """Sets the answered of this GetSmsCampaignStats.

        Number of replies to the SMS  # noqa: E501

        :param answered: The answered of this GetSmsCampaignStats.  # noqa: E501
        :type: int
        """
        if answered is None:
            raise ValueError("Invalid value for `answered`, must not be `None`")  # noqa: E501

        self._answered = answered

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetSmsCampaignStats, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetSmsCampaignStats):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   | 406  | Error. Not Acceptable  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sib_api_v3_sdk
from sib_api_v3_sdk.api.reseller_api import ResellerApi  # noqa: E501
from sib_api_v3_sdk.rest import ApiException


class TestResellerApi(unittest.TestCase):
    """ResellerApi unit test stubs"""

    def setUp(self):
        self.api = sib_api_v3_sdk.api.reseller_api.ResellerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_credits(self):
        """Test case for add_credits

        Add Email and/or SMS credits to a specific child account  # noqa: E501
        """
        pass

    def test_associate_ip_to_child(self):
        """Test case for associate_ip_to_child

        Associate a dedicated IP to the child  # noqa: E501
        """
        pass

    def test_create_child_domain(self):
        """Test case for create_child_domain

        Creates a domain for a child account  # noqa: E501
        """
        pass

    def test_create_reseller_child(self):
        """Test case for create_reseller_child

        Creates a reseller child  # noqa: E501
        """
        pass

    def test_delete_child_domain(self):
        """Test case for delete_child_domain

        Deletes the sender domain of the reseller child based on the childAuthKey and domainName passed  # noqa: E501
        """
        pass

    def test_delete_reseller_child(self):
        """Test case for delete_reseller_child

        Deletes a single reseller child based on the childAuthKey supplied  # noqa: E501
        """
        pass

    def test_dissociate_ip_from_child(self):
        """Test case for dissociate_ip_from_child

        Dissociate a dedicated IP to the child  # noqa: E501
        """
        pass

    def test_get_child_account_creation_status(self):
        """Test case for get_child_account_creation_status

        Returns the status of reseller's child account creation, whether it is successfully created (exists) or not based on the childAuthKey supplied  # noqa: E501
        """
        pass

    def test_get_child_domains(self):
        """Test case for get_child_domains

        Gets all the sender domains of a specific child account  # noqa: E501
        """
        pass

    def test_get_child_info(self):
        """Test case for get_child_info

        Gets the info about a specific child account  # noqa: E501
        """
        pass

    def test_get_reseller_childs(self):
        """Test case for get_reseller_childs

        Gets the list of all reseller's children accounts  # noqa: E501
        """
        pass

    def test_get_sso_token(self):
        """Test case for get_sso_token

        Get session token to access Sendinblue (SSO)  # noqa: E501
        """
        pass

    def test_remove_credits(self):
        """Test case for remove_credits

        Remove Email and/or SMS credits from a specific child account  # noqa: E501
        """
        pass

    def test_update_child_account_status(self):
        """Test case for update_child_account_status

        Updates infos of reseller's child account status based on the childAuthKey supplied  # noqa: E501
        """
        pass

    def test_update_child_domain(self):
        """Test case for update_child_domain

        Updates the sender domain of reseller's child based on the childAuthKey and domainName passed  # noqa: E501
        """
        pass

    def test_update_reseller_child(self):
        """Test case for update_reseller_child

        Updates infos of reseller's child based on the childAuthKey supplied  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
